bayespy.nodes.SwitchingGaussianMarkovChain.get_riemannian_gradient
==================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.get_riemannian_gradient